@@ -28,6 +28,7 @@ describe 'nova::scheduler' do
     it { is_expected.to contain_nova_config('scheduler/max_placement_results').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/enable_isolated_aggregate_filtering').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/query_placement_for_availability_zone').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_nova_config('scheduler/query_placement_for_routed_network_aggregates').with_value('<SERVICE DEFAULT>') }
 
     it { is_expected.to contain_class('nova::availability_zone') }
 
@@ -138,6 +139,14 @@ describe 'nova::scheduler' do
       it { is_expected.to contain_nova_config('scheduler/query_placement_for_availability_zone').with_value(true) }
     end
 
+    context 'with query_placement_for_routed_network_aggregates' do
+      let :params do
+        { :query_placement_for_routed_network_aggregates => true }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/query_placement_for_routed_network_aggregates').with_value(true) }
+    end
+
     context 'with default database parameters' do
       let :pre_condition do
         "include nova::db"
